@@ -20,7 +20,7 @@
 #include "gis/trk/CScrOptTrk.h"
 #include "gis/trk/CDetailsTrk.h"
 #include "gis/trk/CCombineTrk.h"
-#include "gis/CGisProject.h"
+#include "gis/IGisProject.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisWidget.h"
 #include "plot/IPlot.h"
@@ -102,7 +102,7 @@ const QPen CGisItemTrk::penBackground(Qt::white, 5, Qt::SolidLine, Qt::RoundCap,
 QString CGisItemTrk::keyUserFocus;
 
 /// used to create a new track from a part of an existing track
-CGisItemTrk::CGisItemTrk(const QString &name, quint32 idx1, quint32 idx2, const trk_t& srctrk, CGisProject * project)
+CGisItemTrk::CGisItemTrk(const QString &name, quint32 idx1, quint32 idx2, const trk_t& srctrk, IGisProject * project)
     : IGisItem(project, eTypeTrk, -1)
     , penForeground(Qt::blue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
     , drawMode(eDrawNormal)
@@ -154,7 +154,7 @@ CGisItemTrk::CGisItemTrk(const QString &name, quint32 idx1, quint32 idx2, const
 }
 
 /// used to create a copy of track with new parent
-CGisItemTrk::CGisItemTrk(const CGisItemTrk& parentTrk, CGisProject * project, int idx)
+CGisItemTrk::CGisItemTrk(const CGisItemTrk& parentTrk, IGisProject *project, int idx)
     : IGisItem(project, eTypeTrk, idx)
     , penForeground(Qt::blue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
     , drawMode(eDrawNormal)
@@ -172,7 +172,7 @@ CGisItemTrk::CGisItemTrk(const CGisItemTrk& parentTrk, CGisProject * project, in
 }
 
 /// usd to create a track from a line of coordinates
-CGisItemTrk::CGisItemTrk(const QPolygonF& l, const QString& name, CGisProject * project, int idx)
+CGisItemTrk::CGisItemTrk(const QPolygonF& l, const QString& name, IGisProject * project, int idx)
     : IGisItem(project, eTypeTrk, idx)
     , penForeground(Qt::blue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
     , drawMode(eDrawNormal)
@@ -193,7 +193,7 @@ CGisItemTrk::CGisItemTrk(const QPolygonF& l, const QString& name, CGisProject *
 }
 
 /// used to create track from GPX file
-CGisItemTrk::CGisItemTrk(const QDomNode& xml, CGisProject * project)
+CGisItemTrk::CGisItemTrk(const QDomNode& xml, IGisProject *project)
     : IGisItem(project, eTypeTrk, project->childCount())
     , penForeground(Qt::blue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
     , drawMode(eDrawNormal)
@@ -207,6 +207,19 @@ CGisItemTrk::CGisItemTrk(const QDomNode& xml, CGisProject * project)
     setText(0, trk.name);
     setToolTip(0, getInfo());
     genKey();
+
+//    QFile file(trk.name + ".dat");
+//    file.open(QIODevice::WriteOnly);
+//    QDataStream stream(&file);
+//    *this >> stream;
+//    file.close();
+
+//    if(file.open(QIODevice::ReadOnly))
+//    {
+//        QDataStream stream(&file);
+//        *this << stream;
+//        file.close();
+//    }
 }
 
 CGisItemTrk::~CGisItemTrk()
@@ -255,7 +268,7 @@ void CGisItemTrk::getData(QPolygonF &l)
     {
         foreach(const trkpt_t& pt, seg.pts)
         {
-            if(pt.flags & trkpt_t::eDeleted)
+            if(pt.flags & trkpt_t::eHidden)
             {
                 continue;
             }
@@ -555,6 +568,11 @@ void CGisItemTrk::readTrk(const QDomNode& xml, trk_t& trk)
             const QDomNode& xmlTrkpt = xmlTrkpts.item(m);
             readWpt(xmlTrkpt, trkpt);
 
+            trkpt.shdwLon   = trkpt.lon;
+            trkpt.shdwLat   = trkpt.lat;
+            trkpt.shdwEle   = trkpt.ele;
+            trkpt.shdwTime  = trkpt.time;
+
             const QDomNode& ext = xmlTrkpt.namedItem("extensions");
             if(ext.isElement())
             {
@@ -678,7 +696,7 @@ void CGisItemTrk::deriveSecondaryData()
             trkpt_t& trkpt = seg.pts[p];
 
             trkpt.idxTotal = cntTotalPoints++;
-            if(trkpt.flags & trkpt_t::eDeleted)
+            if(trkpt.flags & trkpt_t::eHidden)
             {
                 trkpt.reset();
                 continue;
@@ -764,7 +782,7 @@ void CGisItemTrk::deriveSecondaryData()
         for(int p = 0; p < seg.pts.size(); p++)
         {
             trkpt_t& trkpt = seg.pts[p];
-            if(trkpt.flags & trkpt_t::eDeleted)
+            if(trkpt.flags & trkpt_t::eHidden)
             {
                 continue;
             }
@@ -777,7 +795,7 @@ void CGisItemTrk::deriveSecondaryData()
             while(n>0)
             {
                 trkpt_t & trkpt2 = seg.pts[n];
-                if((trkpt2.flags & trkpt_t::eDeleted) || (trkpt2.ele == NOINT))
+                if((trkpt2.flags & trkpt_t::eHidden) || (trkpt2.ele == NOINT))
                 {
                     n--;
                     continue;
@@ -800,7 +818,7 @@ void CGisItemTrk::deriveSecondaryData()
             while(n < seg.pts.size())
             {
                 trkpt_t & trkpt2 = seg.pts[n];;
-                if((trkpt2.flags & trkpt_t::eDeleted) || (trkpt2.ele == NOINT))
+                if((trkpt2.flags & trkpt_t::eHidden) || (trkpt2.ele == NOINT))
                 {
                     n++;
                     continue;
@@ -890,7 +908,7 @@ bool CGisItemTrk::cut()
         return false;
     }
 
-    CGisProject * project = dynamic_cast<CGisProject*>(parent());
+    IGisProject * project = dynamic_cast<IGisProject*>(parent());
     if(project == 0)
     {
         return false;
@@ -917,7 +935,7 @@ bool CGisItemTrk::cut()
 
 void CGisItemTrk::reverse()
 {
-    CGisProject * project = dynamic_cast<CGisProject*>(parent());
+    IGisProject * project = dynamic_cast<IGisProject*>(parent());
     if(project == 0)
     {
         return;
@@ -955,7 +973,7 @@ void CGisItemTrk::reverse()
 
 void CGisItemTrk::combine()
 {
-    CGisProject * project = dynamic_cast<CGisProject*>(parent());
+    IGisProject * project = dynamic_cast<IGisProject*>(parent());
     if(project == 0)
     {
         return;
@@ -1024,7 +1042,7 @@ void CGisItemTrk::hideSelectedPoints()
 
             if((idx1 < trkpt.idxTotal) && (trkpt.idxTotal < idx2))
             {
-                trkpt.flags |= trkpt_t::eDeleted;
+                trkpt.flags |= trkpt_t::eHidden;
             }
         }
     }
@@ -1060,7 +1078,7 @@ void CGisItemTrk::showSelectedPoints()
 
             if((idx1 < trkpt.idxTotal) && (trkpt.idxTotal < idx2))
             {
-                trkpt.flags &= ~trkpt_t::eDeleted;
+                trkpt.flags &= ~trkpt_t::eHidden;
             }
         }
     }
@@ -1087,7 +1105,7 @@ void CGisItemTrk::copySelectedPoints()
         qSwap(idx1,idx2);
     }
 
-    CGisProject * project = CGisWidget::self().selectProject();
+    IGisProject * project = CGisWidget::self().selectProject();
     if(project == 0)
     {
         return;
@@ -1126,7 +1144,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, QList<QRectF> &b
         {
             foreach(const trkpt_t& pt, seg.pts)
             {
-                if(pt.flags & trkpt_t::eDeleted)
+                if(pt.flags & trkpt_t::eHidden)
                 {
                     continue;
                 }
@@ -1153,7 +1171,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, QList<QRectF> &b
 
                 lineFull << pt1;
 
-                if(pt.flags & trkpt_t::eDeleted)
+                if(pt.flags & trkpt_t::eHidden)
                 {
                     continue;
                 }
@@ -1360,6 +1378,18 @@ void CGisItemTrk::setName(const QString& str)
     changed(QObject::tr("Changed name"));
 }
 
+void CGisItemTrk::setComment(const QString& str)
+{
+    trk.cmt = str;
+    changed(QObject::tr("Changed comment"));
+}
+
+void CGisItemTrk::setDescription(const QString& str)
+{
+    trk.desc = str;
+    changed(QObject::tr("Changed description"));
+}
+
 void CGisItemTrk::setColor(int idx)
 {
     int N = sizeof(lineColors)/sizeof(QColor);
@@ -1426,7 +1456,7 @@ void CGisItemTrk::setMouseFocusByDistance(qreal dist, focusmode_e mode, IPlot *i
         {
             foreach(const trkpt_t& pt, seg.pts)
             {
-                if(pt.flags & trkpt_t::eDeleted)
+                if(pt.flags & trkpt_t::eHidden)
                 {
                     continue;
                 }
@@ -1463,7 +1493,7 @@ void CGisItemTrk::setMouseFocusByTime(quint32 time, focusmode_e mode, IPlot * in
         {
             foreach(const trkpt_t& pt, seg.pts)
             {
-                if(pt.flags & trkpt_t::eDeleted)
+                if(pt.flags & trkpt_t::eHidden)
                 {
                     continue;
                 }
@@ -1551,7 +1581,7 @@ const CGisItemTrk::trkpt_t * CGisItemTrk::getVisibleTrkPtByIndex(quint32 idx)
     {
         foreach(const trkpt_t& pt, seg.pts)
         {
-            if(pt.flags & trkpt_t::eDeleted)
+            if(pt.flags & trkpt_t::eHidden)
             {
                 continue;
             }
