@@ -23,6 +23,7 @@
 #include "ui_IWptIconDialog.h"
 
 class QToolButton;
+class QAction;
 class QListWidgetItem;
 
 class CWptIconDialog : public QDialog, private Ui::IWptIconDialog
@@ -30,13 +31,17 @@ class CWptIconDialog : public QDialog, private Ui::IWptIconDialog
     Q_OBJECT
     public:
         CWptIconDialog(QToolButton * parent);
+        CWptIconDialog(QAction * parent);
         virtual ~CWptIconDialog();
 
     private slots:
         void slotItemClicked(QListWidgetItem * item);
 
     private:
-        QToolButton& button;
+        void setupList(QObject *obj);
+
+        QToolButton * button;
+        QAction     * action;
 
 };
 
