@@ -1457,7 +1457,7 @@ void CMapIMG::loadSubDiv(CFileExt &file, const subdiv_desc_t& subdiv, IGarminStr
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
 
             // skip points outside our current viewport
-            if(isCompletlyOutside(p.poly, viewport))
+            if(isCompletlyOutside(p.pixel, viewport))
             {
                 continue;
             }
@@ -1487,7 +1487,7 @@ void CMapIMG::loadSubDiv(CFileExt &file, const subdiv_desc_t& subdiv, IGarminStr
             pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
 
             // skip points outside our current viewport
-            if(isCompletlyOutside(p.poly, viewport))
+            if(isCompletlyOutside(p.pixel, viewport))
             {
                 continue;
             }
@@ -1526,7 +1526,7 @@ void CMapIMG::loadSubDiv(CFileExt &file, const subdiv_desc_t& subdiv, IGarminStr
             pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, false, pData, pEnd);
 
             // skip points outside our current viewport
-            if(isCompletlyOutside(p.poly, viewport))
+            if(isCompletlyOutside(p.pixel, viewport))
             {
                 continue;
             }
@@ -1551,7 +1551,7 @@ void CMapIMG::loadSubDiv(CFileExt &file, const subdiv_desc_t& subdiv, IGarminStr
             pData += p.decode2(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
 
             // skip points outside our current viewport
-            if(isCompletlyOutside(p.poly, viewport))
+            if(isCompletlyOutside(p.pixel, viewport))
             {
                 continue;
             }
@@ -1614,7 +1614,7 @@ void CMapIMG::drawPolygons(QPainter& p, polytype_t& lines)
                 continue;
             }
 
-            QPolygonF& poly = item->poly;
+            QPolygonF& poly = item->pixel;
 
             map->convertRad2Px(poly);
 
@@ -1678,7 +1678,7 @@ void CMapIMG::drawPolylines(QPainter& p, polytype_t& lines, const QPointF& scale
 
                     pixmapCount++;
 
-                    QPolygonF& poly = item.poly;
+                    QPolygonF& poly = item.pixel;
                     int size        = poly.size();
 
                     if(size < 2)
@@ -1820,7 +1820,7 @@ void CMapIMG::drawPolylines(QPainter& p, polytype_t& lines, const QPointF& scale
 
 void CMapIMG::drawLine(QPainter& p, CGarminPolygon& l, const CGarminTyp::polyline_property& property, const QFontMetricsF& metrics, const QFont& font, const QPointF& scale)
 {
-    QPolygonF& poly     = l.poly;
+    QPolygonF& poly     = l.pixel;
     const int size      = poly.size();
     const int lineWidth = p.pen().width();
 
@@ -1843,8 +1843,8 @@ void CMapIMG::drawLine(QPainter& p, CGarminPolygon& l, const CGarminTyp::polylin
 
 void CMapIMG::drawLine(QPainter& p, const CGarminPolygon& l)
 {
-    const QPolygonF& poly     = l.poly;
-    const int size      = poly.size();
+    const QPolygonF& poly   = l.pixel;
+    const int size          = poly.size();
 
     if(size < 2)
     {
@@ -2472,7 +2472,7 @@ void CMapIMG::getInfoPolylines(const QPoint &pt, QMultiMap<QString, QString>& di
     polytype_t::const_iterator line = polylines.begin();
     while(line != polylines.end())
     {
-        len = line->poly.size();
+        len = line->pixel.size();
         // need at least 2 points
         if(len < 2)
         {
@@ -2483,10 +2483,10 @@ void CMapIMG::getInfoPolylines(const QPoint &pt, QMultiMap<QString, QString>& di
         // see http://local.wasp.uwa.edu.au/~pbourke/geometry/pointline/
         for(i=1; i<len; ++i)
         {
-            p1.u = line->poly[i-1].x();
-            p1.v = line->poly[i-1].y();
-            p2.u = line->poly[i].x();
-            p2.v = line->poly[i].y();
+            p1.u = line->pixel[i-1].x();
+            p1.v = line->pixel[i-1].y();
+            p2.u = line->pixel[i].x();
+            p2.v = line->pixel[i].y();
 
             dx = p2.u - p1.u;
             dy = p2.v - p1.v;
@@ -2590,17 +2590,17 @@ void CMapIMG::getInfoPolygons(const QPoint& pt, QMultiMap<QString, QString>& dic
     while(line != polygons.end())
     {
 
-        npol = line->poly.size();
+        npol = line->pixel.size();
         if(npol > 2)
         {
             c = 0;
             // see http://local.wasp.uwa.edu.au/~pbourke/geometry/insidepoly/
             for (i = 0, j = npol-1; i < npol; j = i++)
             {
-                p1.u = line->poly[j].x();
-                p1.v = line->poly[j].y();
-                p2.u = line->poly[i].x();
-                p2.v = line->poly[i].y();
+                p1.u = line->pixel[j].x();
+                p1.v = line->pixel[j].y();
+                p2.u = line->pixel[i].x();
+                p2.v = line->pixel[i].y();
 
                 if ((((p2.v <= y) && (y < p1.v))  || ((p1.v <= y) && (y < p2.v))) &&
                     (x < (p1.u - p2.u) * (y - p2.v) / (p1.v - p2.v) + p2.u))
@@ -2640,3 +2640,77 @@ void CMapIMG::getInfoPolygons(const QPoint& pt, QMultiMap<QString, QString>& dic
     }
 }
 
+
+static qreal getDistance(const QPolygonF& line, const QPointF& pt, qreal threshold)
+{
+    int i = 0;                   // index into poly line
+    int len;                     // number of points in line
+    QPointF p1, p2;               // the two points of the polyline close to pt
+    qreal dx,dy;                // delta x and y defined by p1 and p2
+    qreal d_p1_p2;              // distance between p1 and p2
+    qreal u;                    // ratio u the tangent point will divide d_p1_p2
+    qreal x,y;                  // coord. (x,y) of the point on line defined by [p1,p2] close to pt
+    qreal distance;             // the distance to the polyline
+
+    qreal d = threshold + 1;
+
+    len = line.size();
+    // see http://local.wasp.uwa.edu.au/~pbourke/geometry/pointline/
+    for(i=1; i<len; ++i)
+    {
+        p1 = line[i-1];
+        p2 = line[i];
+
+        dx = p2.x() - p1.x();
+        dy = p2.y() - p1.y();
+
+        d_p1_p2 = sqrt(dx * dx + dy * dy);
+
+        u = ((pt.x() - p1.x()) * dx + (pt.y() - p1.y()) * dy) / (d_p1_p2 * d_p1_p2);
+
+        if(u < 0.0 || u > 1.0)
+        {
+            continue;
+        }
+
+        x = p1.x() + u * dx;
+        y = p1.y() + u * dy;
+
+        distance = sqrt((x - pt.x())*(x - pt.x()) + (y - pt.y())*(y - pt.y()));
+
+        if(distance < threshold)
+        {
+            d = threshold = distance;
+        }
+    }
+
+    return d;
+}
+
+
+
+bool CMapIMG::findPolylineCloseBy(QPointF& pt1, QPointF& pt2, qint32 threshold, QPolygonF& polyline)
+{
+    foreach(const CGarminPolygon& line, polylines)
+    {
+        if(line.pixel.size() < 2)
+        {
+            continue;
+        }
+        if(0x20 <= line.type && line.type <= 0x25)
+        {
+            continue;
+        }
+
+        qreal dist1 = ::getDistance(line.pixel, pt1, threshold);
+        qreal dist2 = ::getDistance(line.pixel, pt2, threshold);
+
+        if(dist1 < threshold && dist2 < threshold)
+        {
+            polyline  = line.coords;
+            threshold = qMin(dist1, dist2);
+        }
+    }
+
+    return !polyline.isEmpty();
+}
