@@ -18,7 +18,7 @@
 
 #include "map/CMapWMTS.h"
 #include "map/CMapDraw.h"
-#include "map/wmts/CDiskCache.h"
+#include "map/cache/CDiskCache.h"
 #include "units/IUnit.h"
 
 
@@ -38,6 +38,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
     qDebug() << "------------------------------";
     qDebug() << "WTMS: try to open" << filename;
 
+
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
@@ -178,7 +179,16 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
         QString str = xmlTileMatrixSet.namedItem("SupportedCRS").toElement().text();
         char * ptr = str.toLatin1().data();
         OGRSpatialReference oSRS;
-        oSRS.importFromURN(ptr);
+
+        if(str.startsWith("EPSG"))
+        {
+            QStringList tokens = str.split(":");
+            oSRS.importFromEPSG(tokens.last().toInt());
+        }
+        else
+        {
+            oSRS.importFromURN(ptr);
+        }
         oSRS.exportToProj4(&ptr);
 
         qDebug() << ptr;
@@ -229,7 +239,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
 
 CMapWMTS::~CMapWMTS()
 {
-
+//    map->reportStatusToCanvas(name, "");
 }
 
 void CMapWMTS::getLayers(QListWidget& list)
@@ -240,10 +250,6 @@ void CMapWMTS::getLayers(QListWidget& list)
         return;
     }
 
-    QListWidgetItem * item = new QListWidgetItem(tr("--- All ---"), &list);
-    item->setCheckState(Qt::Checked);
-    item->setData(Qt::UserRole, -1);
-
     int i = 0;
     foreach(const layer_t& layer, layers)
     {
@@ -255,6 +261,55 @@ void CMapWMTS::getLayers(QListWidget& list)
     connect(&list, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(slotLayersChanged(QListWidgetItem*)));
 }
 
+void CMapWMTS::saveConfig(QSettings& cfg)
+{
+    IMap::saveConfig(cfg);
+    if(layers.size() < 2)
+    {
+        return;
+    }
+
+    // save indices of enbaled layers
+    QStringList enabled;
+    for(int i = 0; i< layers.size(); i++)
+    {
+        if(layers[i].enabled)
+        {
+            enabled << QString::number(i);
+        }
+    }
+    cfg.setValue("enabledLayers", enabled);
+}
+
+void CMapWMTS::loadConfig(QSettings& cfg)
+{
+    IMap::loadConfig(cfg);
+    if(layers.size() < 2)
+    {
+        return;
+    }
+
+    QStringList enabled;
+    // set all layers to disabled first
+    for(int i = 0; i< layers.size(); i++)
+    {
+        layers[i].enabled = false;
+        enabled << QString::number(i);
+    }
+
+    // enable layers stored in configuration
+    enabled = cfg.value("enabledLayers", enabled).toStringList();
+    foreach(const QString& str, enabled)
+    {
+        int idx = str.toInt();
+        if(idx < layers.size())
+        {
+            layers[idx].enabled = true;
+        }
+    }
+}
+
+
 void CMapWMTS::configureCache()
 {
     delete diskCache;
@@ -316,6 +371,13 @@ void CMapWMTS::slotQueueChanged()
         map->emitSigCanvasUpdate();
     }
 
+    if(timeLastUpdate.elapsed() > 2000)
+    {
+        timeLastUpdate.start();
+        map->emitSigCanvasUpdate();
+    }
+
+
     // report status of pending tiles
     int pending = urlQueue.size() + urlPending.size();
     if(pending)
@@ -364,6 +426,7 @@ void CMapWMTS::draw(IDrawContext::buffer_t& buf)
 {
     QMutexLocker lock(&mutex);
 
+    timeLastUpdate.start();
     urlQueue.clear();
 
     if(map->needsRedraw())
