@@ -63,14 +63,28 @@ IGisLine * CMouseEditArea::getGisLine()
     return dynamic_cast<CGisItemOvlArea*>(CGisWidget::self().getItemByKey(key));
 }
 
+void CMouseEditArea::slotAbort()
+{
+    canvas->reportStatus(key,"");
+    IMouseEditLine::slotAbort();
+}
+
+void CMouseEditArea::slotCopyToOrig()
+{
+    canvas->reportStatus(key,"");
+    IMouseEditLine::slotCopyToOrig();
+}
+
 void CMouseEditArea::slotCopyToNew()
 {
+    canvas->reportStatus(key,"");
+
     if(coords1.size() < 3)
     {
         return;
     }
 
-    CGisProject * project = CGisWidget::self().selectProject();
+    IGisProject * project = CGisWidget::self().selectProject();
     if(project == 0)
     {
         return;
