@@ -53,7 +53,7 @@ CMouseEditTrk::CMouseEditTrk(CGisItemTrk &trk, CGisDraw * gis, CCanvas * parent)
 
 CMouseEditTrk::~CMouseEditTrk()
 {
-    canvas->reportStatus(key, "");
+//    canvas->reportStatus(key,"");
 }
 
 void CMouseEditTrk::mousePressEvent(QMouseEvent * e)
@@ -67,14 +67,29 @@ IGisLine * CMouseEditTrk::getGisLine()
     return dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
 }
 
+void CMouseEditTrk::slotAbort()
+{
+    canvas->reportStatus(key,"");
+    IMouseEditLine::slotAbort();
+}
+
+void CMouseEditTrk::slotCopyToOrig()
+{
+    canvas->reportStatus(key,"");
+    IMouseEditLine::slotCopyToOrig();
+}
+
+
 void CMouseEditTrk::slotCopyToNew()
 {
+    canvas->reportStatus(key,"");
+
     if(coords1.size() < 2)
     {
         return;
     }
 
-    CGisProject * project = CGisWidget::self().selectProject();
+    IGisProject * project = CGisWidget::self().selectProject();
     if(project == 0)
     {
         return;
@@ -98,5 +113,5 @@ void CMouseEditTrk::slotCopyToNew()
     new CGisItemTrk(coords1,name, project, -1);
 
     canvas->resetMouse();
-    canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);            
 }
