@@ -205,6 +205,12 @@ void IMouseEditLine::drawArrows(const QPolygonF &l, QPainter& p)
 
 }
 
+void IMouseEditLine::drawLeadLine(const QPolygonF &l, QPainter& p)
+{
+    p.setPen(QPen(QColor(255,255,0,100), 9, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
+    p.drawPolyline(l);
+}
+
 void IMouseEditLine::draw(QPainter& p, bool needsRedraw, const QRect &rect)
 {
     if(needsRedraw)
@@ -215,10 +221,9 @@ void IMouseEditLine::draw(QPainter& p, bool needsRedraw, const QRect &rect)
         gis->convertRad2Px(newLine);
     }
 
-
-
     switch(state)
     {
+        case eStateMoveMap:
         case eStateIdle:
         case eStatePointSelected:
             drawArrows(line, p);
@@ -251,14 +256,39 @@ void IMouseEditLine::draw(QPainter& p, bool needsRedraw, const QRect &rect)
             break;
 
         case eStateAddPointFwd:
-        case eStateAddPointBwd:
         {
-            QPolygonF l = line.mid(0, idxStart + 1) + newLine + line.mid(idxStop, -1);
+            QPolygonF l;
+            if(subLinePixel.isEmpty())
+            {
+                l = line.mid(0, idxStart) + newLine + line.mid(idxStop, -1);
+            }
+            else
+            {
+                l = line.mid(0, idxStart) + newLine.mid(0, newLine.size() - 2) + subLinePixel + line.mid(idxStop, -1);
+            }
+            drawLeadLine(leadLinePixel, p);
             drawArrows(l, p);
             drawLine(l, p);            
             drawBullets(l, p);
             break;
         }
+        case eStateAddPointBwd:
+        {
+            QPolygonF l;
+            if(subLinePixel.isEmpty())
+            {
+                l = line.mid(0, idxStart + 1) + newLine + line.mid(idxStop + 1, -1);
+            }
+            else
+            {
+                l = line.mid(0, idxStart + 1) + subLinePixel + newLine.mid(2, -1) + line.mid(idxStop + 1, -1);
+            }
+            drawLeadLine(leadLinePixel, p);
+            drawArrows(l, p);
+            drawLine(l, p);
+            drawBullets(l, p);
+            break;
+        }
         default:;
     }
 
@@ -310,17 +340,21 @@ void IMouseEditLine::mousePressEvent(QMouseEvent * e)
                 {
                     if(state == eStateAddPointBwd)
                     {
+                        // remove first point, which is the current moving point
                         newCoords.pop_front();
+                        save = coords1.mid(0, idxStart + 1) + newCoords + coords1.mid(idxStop + 1, -1);
                     }
 
                     if(state == eStateAddPointFwd)
                     {
+                        // remove last point, which is the current moving point
                         newCoords.pop_back();
+                        save = coords1.mid(0, idxStart) + newCoords + coords1.mid(idxStop, -1);
                     }
 
-                    save        = coords1.mid(0, idxStart + 1) + newCoords + coords1.mid(idxStop, -1);
-                    coords1     = save;
-                    line        = coords1;
+
+                    coords1 = save;
+                    line    = coords1;
                     gis->convertRad2Px(line);
                 }
 
@@ -470,13 +504,38 @@ void IMouseEditLine::mousePressEvent(QMouseEvent * e)
             }
             case eStateAddPointFwd:
             {
+                if(!subLineCoord.isEmpty())
+                {
+                    newLine.pop_back();
+                    newLine.pop_back();
+                    newLine     = newLine + subLinePixel;
+                    newCoords.pop_back();
+                    newCoords.pop_back();
+                    newCoords   = newCoords + subLineCoord;
+
+                    subLineCoord.clear();
+                    subLinePixel.clear();
+                }
                 newLine.append(newLine.last());
                 newCoords.append(newCoords.last());
-                idxFocus++;
+                idxFocus = newLine.size() - 1;
                 break;
             }
             case eStateAddPointBwd:
             {
+                if(!subLineCoord.isEmpty())
+                {
+                    newLine.pop_front();
+                    newLine.pop_front();
+                    newLine = subLinePixel + newLine;
+                    newCoords.pop_front();
+                    newCoords.pop_front();
+                    newCoords = subLineCoord + newCoords;
+
+                    subLineCoord.clear();
+                    subLinePixel.clear();
+                }
+
                 newLine.prepend(newLine.first());
                 newCoords.prepend(newCoords.first());
                 idxFocus = 0;
@@ -556,6 +615,47 @@ void IMouseEditLine::mouseMoveEvent(QMouseEvent * e)
             gis->convertPx2Rad(pt);
             newCoords[idxFocus] = pt;
 
+
+            leadLineCoord.clear();
+            leadLinePixel.clear();
+            subLinePixel.clear();
+            subLineCoord.clear();
+
+
+            // find polyline to snap
+            QPointF px1;
+            QPointF px2;
+            if(newLine.size() > 1)
+            {                
+                px1 = state == eStateAddPointFwd ? newLine[idxFocus - 1] : newLine[1];
+                px2 = newLine[idxFocus];
+            }
+
+            if(canvas->findPolylineCloseBy(px2, px2, 10, leadLineCoord))
+            {
+
+                leadLinePixel = leadLineCoord;
+                gis->convertRad2Px(leadLinePixel);
+
+                segment_t result;
+                GPS_Math_SubPolyline(px1, px2, 10, leadLinePixel, result);
+                result.apply(leadLineCoord, leadLinePixel, subLineCoord, subLinePixel, gis);
+
+                if(state == eStateAddPointBwd)
+                {
+                    QPolygonF tmp1;
+                    QPolygonF tmp2;
+                    for(int i = 0; i < subLineCoord.size(); i++)
+                    {
+                        tmp1.push_front(subLineCoord[i]);
+                        tmp2.push_front(subLinePixel[i]);
+                    }
+                    subLineCoord = tmp1;
+                    subLinePixel = tmp2;
+                }
+            }
+
+
             canvas->update();
             break;
 
@@ -691,11 +791,17 @@ void IMouseEditLine::slotAddPoint1()
     }
     scrOptPoint->deleteLater();
 
-    // set point with focus as temporary initial point
-    newCoords.clear();    
-    newCoords << coords1[idxFocus];
+    newCoords.clear();
     newLine.clear();
-    newLine   << line[idxFocus];
+    /*
+        Adding points will work completely on newLine and newCoords until the
+        line segment is taken over or dumped. The current point of focus is
+        added twice. The first time as fixed starting point of the tmeporary
+        newLine. And the second time as initial point to be moved by the mouse.
+
+    */
+    newCoords << coords1[idxFocus]  << coords1[idxFocus];
+    newLine   << line[idxFocus]     << line[idxFocus];
 
     // mark gap to insert points
     idxStart = idxFocus - 1;
@@ -718,20 +824,31 @@ void IMouseEditLine::slotAddPoint2()
     {
         return;
     }
-    scrOptPoint->deleteLater();
 
-    // set point with focus as temporary initial point
+    if(!scrOptPoint.isNull())
+    {
+        scrOptPoint->deleteLater();
+    }
+
+
     newCoords.clear();
-    newCoords << coords1[idxFocus];    
     newLine.clear();
-    newLine   << line[idxFocus];
+    /*
+        Adding points will work completely on newLine and newCoords until the
+        line segment is taken over or dumped. The current point of focus is
+        added twice. The first time as fixed starting point of the tmeporary
+        newLine. And the second time as initial point to be moved by the mouse.
+
+    */
+    newCoords << coords1[idxFocus]  << coords1[idxFocus];
+    newLine   << line[idxFocus]     << line[idxFocus];
 
     // mark gap to insert points
     idxStart = idxFocus;
     idxStop  = idxFocus + 1;
 
     // set focus to first point in newLine
-    idxFocus = 0;
+    idxFocus = 1;
 
     state   = eStateAddPointFwd;
     cursor  = QCursor(QPixmap(":/cursors/cursorAdd.png"),0,0);
@@ -771,3 +888,4 @@ void IMouseEditLine::slotCopyToOrig()
     canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
 }
 
+
